#
# spec file for package python-linux-procfs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

Name:           python-linux-procfs
Version:        0.7.3
Release:        4.1
Summary:        Linux /proc abstraction classes
License:        GPL-2.0-only
URL:            https://rt.wiki.kernel.org/index.php/Tuna
Source:         https://cdn.kernel.org/pub/software/libs/python/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
%if %{with libalternatives}
Requires:       alts
BuildRequires:  alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
BuildArch:      noarch
%python_subpackages

%description
Abstractions to extract information from the Linux kernel /proc files.

%prep
%autosetup -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pflags
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec bitmasklist_test.py

%pre
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative pflags

%post
%python_install_alternative pflags

%postun
%python_uninstall_alternative pflags

%files %{python_files}
%license COPYING
%python_alternative %{_bindir}/pflags
%{python_sitelib}/procfs
%{python_sitelib}/python_linux_procfs-%{version}.dist-info

%changelog
* Wed Mar 26 2025 Nico Krapp <nico.krapp@suse.com>
- Use libalternatives instead of update-alternatives, bsc#1240096
* Wed Jan 29 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Thu Feb 15 2024 pgajdos@suse.com
- align license tag with COPYING
* Wed Nov 22 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.3:
  * python 3.12 support (remove distutils)
  * drop spec files and add SPDX licenses
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.1:
  * Correct VERSION number in procfs.py
  * Use f-strings
  * Add missing open in with statement
  * Use sys.exit and add some docstrings
  * Add tar.xz and asc files to gitignore
  * Fix traceback with non-utf8 chars in the /proc/PID/cmdline
  * Propagate error to user if a pid is completed
  * pflags: Handle pids that completed
  * Makefile: Add ctags
  * Remove procfs/sysctl.py
  * Various clean-ups
  * Fix UnicodeDecodeError
  * Fix more spacing problems with procfs.py
  * procfs.py: Simplify is_s390
  * procfs.py: Fix a few more style problems
  * clean-ups for recent python formating regarding spacing, tabs, etc
  * Fix to parse the number of cpus correctly on s390(x)
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Dec 11 2018 Tomáš Chvátal <tchvatal@suse.com>
- Switch to full singlespec for others to use with all python
  variants as the targets are defined in distro setup (ie py3 only
  on SLE15)
* Mon Dec 10 2018 trenn@suse.de
- Package needed for latest tuned (bsc#1071436)
- correct version in first changelog entry
- only xz, removed gz tarball
- called test executable in %%check section
- Removed never/unused patch
- Use python3_install and python3_build, this package is only
  needed for python3 intentionally
- Remove %%{python_files} from %%files section again, this package
  is for python3 intended only
- Run spec_cleaner
- Use pycache_only
* Fri Dec  7 2018 trenn@suse.de
- Inital version 0.6 submission
